==> vst3sdk-docs-3.7.13_build_42-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/vstsdk/dir_ef3d652449b8d3a1e622cc158f538a33.js <==
var dir_ef3d652449b8d3a1e622cc158f538a33 =
[
    [ "aaxwrapper", "dir_a72c21144a3aa0dabf116282c5a0038c.html", "dir_a72c21144a3aa0dabf116282c5a0038c" ],
    [ "auwrapper", "dir_2e885b037767c89fc7032b3bad7380bb.html", "dir_2e885b037767c89fc7032b3bad7380bb" ],
    [ "basewrapper", "dir_5b400018c1e0e8250122bdd73c88aee7.html", "dir_5b400018c1e0e8250122bdd73c88aee7" ],
    [ "hosting", "dir_9d0a1c96bcf639e3da34210cb03957b4.html", "dir_9d0a1c96bcf639e3da34210cb03957b4" ],
    [ "interappaudio", "dir_2c00dc52d9ac6a148a4d1bfb9572a299.html", "dir_2c00dc52d9ac6a148a4d1bfb9572a299" ],
    [ "testsuite", "dir_8c2a42e5d0a6b85e7b1cdc27019f43b5.html", "dir_8c2a42e5d0a6b85e7b1cdc27019f43b5" ],
    [ "utility", "dir_1c80b6ba57cec87ca8b9a5e1bda0dd13.html", "dir_1c80b6ba57cec87ca8b9a5e1bda0dd13" ],
    [ "doc_public_sdk.h", "doc__public__sdk_8h.html", null ],
    [ "doc_public_sdk_limited.h", "doc__public__sdk__limited_8h.html", null ],
    [ "vstaudioeffect.cpp", "vstaudioeffect_8cpp.html", null ],
    [ "vstaudioeffect.h", "vstaudioeffect_8h.html", null ],
    [ "vstaudioprocessoralgo.h", "vstaudioprocessoralgo_8h.html", "vstaudioprocessoralgo_8h" ],
    [ "vstbus.cpp", "vstbus_8cpp.html", null ],
    [ "vstbus.h", "vstbus_8h.html", null ],
    [ "vstbypassprocessor.h", "vstbypassprocessor_8h.html", "vstbypassprocessor_8h" ],
    [ "vstcomponent.cpp", "vstcomponent_8cpp.html", "vstcomponent_8cpp" ],
    [ "vstcomponent.h", "vstcomponent_8h.html", "vstcomponent_8h" ],
    [ "vstcomponentbase.cpp", "vstcomponentbase_8cpp.html", null ],
    [ "vstcomponentbase.h", "vstcomponentbase_8h.html", null ],
    [ "vsteditcontroller.cpp", "vsteditcontroller_8cpp.html", null ],
    [ "vsteditcontroller.h", "vsteditcontroller_8h.html", null ],
    [ "vsteventshelper.h", "vsteventshelper_8h.html", "vsteventshelper_8h" ],
    [ "vstgui_win32_bundle_support.cpp", "vstgui__win32__bundle__support_8cpp.html", "vstgui__win32__bundle__support_8cpp" ],
    [ "vstgui_win32_bundle_support.h", "vstgui__win32__bundle__support_8h.html", "vstgui__win32__bundle__support_8h" ],
    [ "vstguieditor.cpp", "vstguieditor_8cpp.html", "vstguieditor_8cpp" ],
    [ "vstguieditor.h", "vstguieditor_8h.html", "vstguieditor_8h" ],
    [ "vsthelpers.h", "vsthelpers_8h.html", "vsthelpers_8h" ],
    [ "vstinitiids.cpp", "vstinitiids_8cpp.html", null ],
    [ "vstnoteexpressiontypes.cpp", "vstnoteexpressiontypes_8cpp.html", null ],
    [ "vstnoteexpressiontypes.h", "vstnoteexpressiontypes_8h.html", null ],
    [ "vstparameters.cpp", "vstparameters_8cpp.html", null ],
    [ "vstparameters.h", "vstparameters_8h.html", null ],
    [ "vstpresetfile.cpp", "vstpresetfile_8cpp.html", "vstpresetfile_8cpp" ],
    [ "vstpresetfile.h", "vstpresetfile_8h.html", "vstpresetfile_8h" ],
    [ "vstrepresentation.cpp", "vstrepresentation_8cpp.html", "vstrepresentation_8cpp" ],
    [ "vstrepresentation.h", "vstrepresentation_8h.html", null ],
    [ "vstsinglecomponenteffect.cpp", "vstsinglecomponenteffect_8cpp.html", "vstsinglecomponenteffect_8cpp" ],
    [ "vstsinglecomponenteffect.h", "vstsinglecomponenteffect_8h.html", "vstsinglecomponenteffect_8h" ],
    [ "vstspeakerarray.h", "vstspeakerarray_8h.html", [
      [ "SpeakerArray", "classSteinberg_1_1Vst_1_1SpeakerArray.html", "classSteinberg_1_1Vst_1_1SpeakerArray" ]
    ] ]
];

==> vst3sdk-docs-3.8.0_build_66-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/vstsdk/dir_ef3d652449b8d3a1e622cc158f538a33.js <==
var dir_ef3d652449b8d3a1e622cc158f538a33 =
[
    [ "aaxwrapper", "dir_a72c21144a3aa0dabf116282c5a0038c.html", "dir_a72c21144a3aa0dabf116282c5a0038c" ],
    [ "auwrapper", "dir_2e885b037767c89fc7032b3bad7380bb.html", "dir_2e885b037767c89fc7032b3bad7380bb" ],
    [ "basewrapper", "dir_5b400018c1e0e8250122bdd73c88aee7.html", "dir_5b400018c1e0e8250122bdd73c88aee7" ],
    [ "hosting", "dir_9d0a1c96bcf639e3da34210cb03957b4.html", "dir_9d0a1c96bcf639e3da34210cb03957b4" ],
    [ "interappaudio", "dir_2c00dc52d9ac6a148a4d1bfb9572a299.html", "dir_2c00dc52d9ac6a148a4d1bfb9572a299" ],
    [ "moduleinfo", "dir_e59c0a68fdee6fa86f9e7397f43c5721.html", "dir_e59c0a68fdee6fa86f9e7397f43c5721" ],
    [ "testsuite", "dir_8c2a42e5d0a6b85e7b1cdc27019f43b5.html", "dir_8c2a42e5d0a6b85e7b1cdc27019f43b5" ],
    [ "utility", "dir_1c80b6ba57cec87ca8b9a5e1bda0dd13.html", "dir_1c80b6ba57cec87ca8b9a5e1bda0dd13" ],
    [ "doc_public_sdk_limited.h", "doc__public__sdk__limited_8h.html", null ],
    [ "vstaudioeffect.cpp", "vstaudioeffect_8cpp.html", null ],
    [ "vstaudioeffect.h", "vstaudioeffect_8h.html", null ],
    [ "vstaudioprocessoralgo.h", "vstaudioprocessoralgo_8h.html", "vstaudioprocessoralgo_8h" ],
    [ "vstbus.cpp", "vstbus_8cpp.html", null ],
    [ "vstbus.h", "vstbus_8h.html", null ],
    [ "vstbypassprocessor.h", "vstbypassprocessor_8h.html", "vstbypassprocessor_8h" ],
    [ "vstcomponent.cpp", "vstcomponent_8cpp.html", "vstcomponent_8cpp" ],
    [ "vstcomponent.h", "vstcomponent_8h.html", "vstcomponent_8h" ],
    [ "vstcomponentbase.cpp", "vstcomponentbase_8cpp.html", null ],
    [ "vstcomponentbase.h", "vstcomponentbase_8h.html", null ],
    [ "vsteditcontroller.cpp", "vsteditcontroller_8cpp.html", null ],
    [ "vsteditcontroller.h", "vsteditcontroller_8h.html", null ],
    [ "vsteventshelper.h", "vsteventshelper_8h.html", "vsteventshelper_8h" ],
    [ "vstgui_linux_runloop_support.cpp", "vstgui__linux__runloop__support_8cpp.html", "vstgui__linux__runloop__support_8cpp" ],
    [ "vstgui_linux_runloop_support.h", "vstgui__linux__runloop__support_8h.html", "vstgui__linux__runloop__support_8h" ],
    [ "vstgui_win32_bundle_support.cpp", "vstgui__win32__bundle__support_8cpp.html", "vstgui__win32__bundle__support_8cpp" ],
    [ "vstgui_win32_bundle_support.h", "vstgui__win32__bundle__support_8h.html", "vstgui__win32__bundle__support_8h" ],
    [ "vstguieditor.cpp", "vstguieditor_8cpp.html", "vstguieditor_8cpp" ],
    [ "vstguieditor.h", "vstguieditor_8h.html", "vstguieditor_8h" ],
    [ "vsthelpers.h", "vsthelpers_8h.html", "vsthelpers_8h" ],
    [ "vstinitiids.cpp", "vstinitiids_8cpp.html", null ],
    [ "vstnoteexpressiontypes.cpp", "vstnoteexpressiontypes_8cpp.html", null ],
    [ "vstnoteexpressiontypes.h", "vstnoteexpressiontypes_8h.html", null ],
    [ "vstparameters.cpp", "vstparameters_8cpp.html", null ],
    [ "vstparameters.h", "vstparameters_8h.html", null ],
    [ "vstpresetfile.cpp", "vstpresetfile_8cpp.html", "vstpresetfile_8cpp" ],
    [ "vstpresetfile.h", "vstpresetfile_8h.html", "vstpresetfile_8h" ],
    [ "vstrepresentation.cpp", "vstrepresentation_8cpp.html", "vstrepresentation_8cpp" ],
    [ "vstrepresentation.h", "vstrepresentation_8h.html", null ],
    [ "vstsinglecomponenteffect.cpp", "vstsinglecomponenteffect_8cpp.html", "vstsinglecomponenteffect_8cpp" ],
    [ "vstsinglecomponenteffect.h", "vstsinglecomponenteffect_8h.html", "vstsinglecomponenteffect_8h" ],
    [ "vstspeakerarray.h", "vstspeakerarray_8h.html", "vstspeakerarray_8h" ]
];
